#' h2 jk matrix for 62 traits
#'
#' Example h2 jk matrix used in the vignette and examples.
#'
#' @format A numeric matrix.
#' @source Internal simulation
"h2_vector_mat"
